import QtQuick 1.0
import "./js/Util.js" as Util

Item {
    id: container

    Visual{
        id: visual
    }

    property string fontName : visual.defaultFontFamily
    property int  fontSize : visual.defaultFontSize
    property color  fontColor : visual.defaultFontColor
    property color  fontColorLink : visual.defaultFontColorLink
    property color  fontColorButton : visual.defaultFontColorButton
    property double  margins : visual.margins
    property int  scrollBarWidth : visual.scrollBarWidth

    // Default values, change when using
    width: 360
    height: 640

    Component.onCompleted: {
        Util.log("basicInfoView Loaded")        

    }

    BasicInfoModel{
        id: basicInfoModel

        onStatusChanged: {
            if (status == XmlListModel.Ready) {             
                phillogo.source = basicInfoModel.get(0).phillogo
                description.text = basicInfoModel.get(0).description
                name.text = basicInfoModel.get(0).name
                lrt1logo.source = basicInfoModel.get(0).lrtlogo
                lrt1Title.text = basicInfoModel.get(0).lrt1Title
                lrt1Desc.text = basicInfoModel.get(0).lrt1Desc
                lrt2logo.source = basicInfoModel.get(0).lrtlogo
                lrt2Title.text = basicInfoModel.get(0).lrt2Title
                lrt2Desc.text = basicInfoModel.get(0).lrt2Desc
                mrt3logo.source = basicInfoModel.get(0).mrtlogo
                mrt3Title.text = basicInfoModel.get(0).mrt3Title
                mrt3Desc.text = basicInfoModel.get(0).mrt3Desc
                Util.log("Loaded Data!!!!!" + phillogo.source )
            }
        }
    }



    Flickable{
        id: flicker
        anchors{
            fill: container
            margins: container.margins
        }
        contentWidth: width
        contentHeight: column.height                   


        Column{
            id: column
            width: parent.contentWidth
            spacing: container.margins + 10
            Column{
                spacing: container.margins
                Row{
                    spacing: container.margins
                    Image {
                        id: phillogo
                        fillMode: "PreserveAspectFit"
                        smooth: true
                        height: 60

                    }
                    Text{
                        id: name
                        smooth: true
                        //width: flicker.width
                        anchors.verticalCenter: phillogo.verticalCenter
                        //anchors.bottom: phillogo.bottom
                        anchors.margins: container.margins
                        font.pointSize: visual.basicInfoViewTitleFontSize - 3
                        font.family: container.fontName
                        font.bold: true
                        //                style: Text.Raised
                        //                styleColor: "#ffffff"
                        color: visual.basicInfoViewTitleFontColor
                    }                    
                }
                Text{
                    id: description
                    wrapMode: Text.WordWrap
                    width: flicker.width
                    color: container.fontColor
                    font{
                        family: container.fontName
                        pointSize: visual.basicInfoViewFontSize
                    }
                }
            }
            Column{
                spacing: container.margins
                Row{
                    spacing: container.margins
                    Image{
                        id:lrt1logo
                        height: 40
                        fillMode: Image.PreserveAspectFit
                    }
                    Text{
                        id :lrt1Title
                        anchors.verticalCenter: lrt1logo.verticalCenter
                        //anchors.bottom: phillogo.bottom
                        anchors.margins: container.margins
                        font.pointSize: visual.basicInfoViewTitleFontSize
                        font.family: container.fontName
                        font.bold: true
                        //                style: Text.Raised
                        //                styleColor: "#ffffff"
                        color: visual.lrt1TitleColor
                    }
                }
                Text{
                    id: lrt1Desc
                    wrapMode: Text.WordWrap
                    width: flicker.width
                    color: container.fontColor
                    font{
                        family: container.fontName
                        pointSize: visual.basicInfoViewFontSize
                    }
                }
            }
            Column{
                spacing: container.margins
                Row{
                    spacing: container.margins
                    Image{
                        id:lrt2logo
                        height: 40
                        fillMode: Image.PreserveAspectFit
                    }
                    Text{
                        id :lrt2Title
                        anchors.verticalCenter: lrt2logo.verticalCenter
                        //anchors.bottom: phillogo.bottom
                        anchors.margins: container.margins
                        font.pointSize: visual.basicInfoViewTitleFontSize
                        font.family: container.fontName
                        font.bold: true
                        //                style: Text.Raised
                        //                styleColor: "#ffffff"
                        color: visual.lrt2TitleColor
                    }
                }
                Text{
                    id: lrt2Desc
                    wrapMode: Text.WordWrap
                    width: flicker.width
                    color: container.fontColor
                    font{
                        family: container.fontName
                        pointSize: visual.basicInfoViewFontSize
                    }
                }
            }
            Column{
                spacing: container.margins
                Row{
                    spacing: container.margins
                    Image{
                        id:mrt3logo
                        height: 40
                        fillMode: Image.PreserveAspectFit
                    }
                    Text{
                        id :mrt3Title
                        anchors.verticalCenter:mrt3logo.verticalCenter
                        //anchors.bottom: phillogo.bottom
                        anchors.margins: container.margins
                        font.pointSize: visual.basicInfoViewTitleFontSize
                        font.family: container.fontName
                        font.bold: true
                        //                style: Text.Raised
                        //                styleColor: "#ffffff"
                        color: visual.mrt3TitleColor
                    }
                }
                Text{
                    id: mrt3Desc
                    wrapMode: Text.WordWrap
                    width: flicker.width
                    color: container.fontColor
                    font{
                        family: container.fontName
                        pointSize: visual.basicInfoViewFontSize
                    }
                }
            }
        }
    }

    // ScrollBar indicator. Take the bottommost search field height into account.
    ScrollBar{
        id: scrollBar
        scrollArea: flicker
        height: flicker.height
        width: container.scrollBarWidth
        anchors.right: container.right
    }
}
