import QtQuick 1.0

// Dialog Item consists of Fader and one item, two states and animations between them.
// - Fader: Dimms the background & captures mouse events.
// - Item Shows the Dialog with some text on it and with Ok/Cancel buttons.
// - States: Handles the opacity changes for the dialog item.
// - Transitions: Transitions between the dialog showing/hiding states smoothly.
Item {
    id: modalDialog

    // The width and height are meant to be replaced by the parent, e.g. by
    // using anchors.fill. So remember to modify these when instantiating
    // a ModalNote. Otherwise it'll just use S³ default resolution.
    width: screen.displayHeight
    height: screen.displayWidth

    // Text to be shown within the modal dialog.
    // Should always be modified by parent.
    property string text: "NOT SET"

    // Font properties, that can (and should) be changed by parent.
    property string fontName: "Helvetica"
    property int fontSize: 18
    property int buttonFontSize: fontSize
    property int textFontSize: fontSize
    property color fontColor: "white"
    property color fontColorButton: "black"


    // These components are used to change button look and feel.
    // Currently disabled (check Button components below).
//    property Component buttonBackground
//    property Component buttonBackgroundPressed
    property bool showCancelButton: true

    // Signals that are emitted from Ok/Cancel -buttons. Parent should
    // define handlers for these to react to user selection.
    signal accepted
    signal cancelled

    // This function will start showing the dialog.
    function show () {
        modalDialog.state = "show";
    }

    // Use Fader component to dim the background & prevent key/touch events
    // to items lying underneath the dialog. I.e. makes the dialog "modal".
    Fader {
        id: fadeRect
        anchors.fill: parent

        // Bind main dialog's state with fader's corresponding states.
        state: modalDialog.state == "show" ? "faded" : ""
        transitionDuration: 300 // Use the same transition time as for the main dialog
    }

    // Rectangle that shows some dialog graphics, text and "Ok" & "Cancel" buttons.
    // Consists of rectangle containing some text & two buttons in a row.
    Item {
        id: dialog

        opacity: 0
        anchors.left: parent.left
        anchors.top: parent.top
        width: parent.width
        height: column.height
        //anchors.verticalCenter: parent.verticalCenter
        anchors.topMargin: 10
        anchors.leftMargin: 8
        Column {
            id: column
            width: parent.width

            //anchors.centerIn: parent.horizontalCenter
            spacing: 5
            // Given text, centered within the dialog.
            Text {
                id: dlgText
                text : "LRT 1(Yellow Line)"
                width: parent.width
                //text: modalDialog.text
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize: modalDialog.textFontSize + 2
                    bold : true
                }
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignLeft
            }
//            Text{
//                text: "  A.Single Journey Ticket"
//                width: parent.width
//                color: modalDialog.fontColor
//                font {
//                    family: modalDialog.fontName
//                    pointSize: 8 // modalDialog.textFontSize
//                   // bold:true
//                }
//                horizontalAlignment: Text.AlignLeft
//            }
            Text{
                text: "        Php 12.00 (1-4 stations)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize: modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        Php 15.00 (5 stations onwards)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize: modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        Php 20.00 (End to end travelling)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize:  modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }

//            Text{
//                text: "  A.Stored Value Ticket : Php.100.00"
//                width: parent.width
//                color: modalDialog.fontColor
//                font {
//                    family: modalDialog.fontName
//                    pointSize: 8 // modalDialog.textFontSize
//                   // bold:true
//                }
//                horizontalAlignment: Text.AlignLeft
//            }
            Text {
                id: dlgText2
                text : "LRT 2(Purple Line)"
                width: parent.width
                //text: modalDialog.text
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize: modalDialog.textFontSize + 2
                    bold : true
                }
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignLeft
            }
//            Text{
//                text: "  A.Single Journey Ticket"
//                width: parent.width
//                color: modalDialog.fontColor
//                font {
//                    family: modalDialog.fontName
//                    pointSize: 8 // modalDialog.textFontSize
//                   // bold:true
//                }
//                horizontalAlignment: Text.AlignLeft
//            }
            Text{
                text: "        Php 12.00 (1-3 stations)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize:  modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        Php 13.00 (4-6 stations)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize:  modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        Php 14.00 (7-9 stations)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize:  modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        Php 15.00 (End to end travelling)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize: modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }

//            Text{
//                text: "  A.Stored Value Ticket : Php.100.00"
//                width: parent.width
//                color: modalDialog.fontColor
//                font {
//                    family: modalDialog.fontName
//                    pointSize: 8 // modalDialog.textFontSize
//                   // bold:true
//                }
//                horizontalAlignment: Text.AlignLeft
//            }
            Text {
                id: dlgText3
                text : "MRT 3(Blue Line)"
                width: parent.width
                //text: modalDialog.text
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize:  modalDialog.textFontSize + 2
                    bold : true
                }
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignLeft
            }
//            Text{
//                text: "  A.Single Journey Ticket"
//                width: parent.width
//                color: modalDialog.fontColor
//                font {
//                    family: modalDialog.fontName
//                    pointSize: 8 // modalDialog.textFontSize
//                   // bold:true
//                }
//                horizontalAlignment: Text.AlignLeft
//            }
            Text{
                text: "        Php 10.00 (1-3 stations)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize:  modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        Php 11.00 (4-5 stations)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize: modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        Php 12.00 (6-8 stations)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize: modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        Php 14.00 (9-11 stations)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize:  modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        Php 15.00 (End to end travelling)"
                width: parent.width
                color: modalDialog.fontColor
                font {
                    family: modalDialog.fontName
                    pointSize:  modalDialog.textFontSize
                }
                horizontalAlignment: Text.AlignLeft
            }
            Text{
                text: "        *All fares are based on Single Journey Ticket"
                width: parent.width
                height: 20
                verticalAlignment: Text.AlignBottom
                color: "yellow"
                font {
                    family: modalDialog.fontName
                    pointSize:  modalDialog.textFontSize -4
                }
                horizontalAlignment: Text.AlignLeft
            }
            // Under the text field there's two clickable buttons.
            Row {
                spacing: 10
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    bottomMargin: 25
                }

                Button2 {
                    id: okButton
                    text: "OK"
                    fontColor: modalDialog.fontColorButton
                    fontName: modalDialog.fontName
                    fontSize: modalDialog.buttonFontSize

                    // Enable these, if you would want to change the button
                    // look 'n' feel from your main qml.
//                    bg: modalDialog.buttonBackground
//                    bgPressed: modalDialog.buttonBackgroundPressed

                    // On click emit "accepted" signal via the main level dialog Item
                    // and hide the dialog.
                    onClicked: {
                        console.log("Dialog was being accepted.");
                        modalDialog.state = "";
                        modalDialog.accepted();
                    }
                }

                Button2 {
                    id: cancelButton
                    text: "Cancel"
                    fontColor: modalDialog.fontColorButton
                    fontName: modalDialog.fontName
                    fontSize: modalDialog.buttonFontSize

                    // Enable these, if you would want to change the button
                    // look 'n' feel from your main qml.
//                    bg: modalDialog.buttonBackground
//                    bgPressed: modalDialog.buttonBackgroundPressed
                    visible: modalDialog.showCancelButton

                    // On click emit "cancelled" signal via the main level dialog Item
                    // and hide the dialog.
                    onClicked: {
                        console.log("Dialog was being cancelled");
                        modalDialog.state = "";
                        modalDialog.cancelled();
                    }
                }
            } // Row
        }

    }

    // Originally, keep the dialog hidden. When the "show" state is being entered,
    // we show the dialog with opacity 1. The Fader component has its own
    // states & transitions, which are triggered simultaneously with ModalDialog's
    // own transitions.
    states: [
        State {
            name: ""
            PropertyChanges {
                target: dialog
                opacity: 0
            }
        },
        State {
            name: "show"
            PropertyChanges {
                target: dialog
                opacity: 1
            }
        }
    ]

    // The transitions handle changing the dialog states smoothly by animating the opacity.
    transitions: [
        Transition {
            from: ""
            to: "show"
            SequentialAnimation {
                NumberAnimation { properties: "opacity"; easing.type: Easing.Linear; duration: 300 }
            }
        },
        Transition {
            from: "show"
            to: ""
            NumberAnimation { properties: "opacity"; easing.type: Easing.Linear; duration: 300 }
        }
    ]
}
