import QtQuick 1.0
import "./js/Util.js" as Util

Item {
    id: container

    signal stationMapClicked( string stationId )

    Visual{
        id: visual
    }

    property string fontName: visual.defaultFontFamily
    property int fontSize: visual.defaultFontSize
    property int fontSizeTitle: visual.stationInfoViewTitleSize
    property color fontColor: visual.stationInfoViewDescFontColor
    property color fontColorTitle: visual.stationInfoViewDescFontColor
    property color fontColorLink: visual.defaultFontColorLink
    property double margins: visual.margins
    property int spacing: visual.spacing

    property int scrollBarWidth: visual.scrollBarWidth

    property string selectedStationId: appState.selectedStationId
    property string selectedStationName: appState.selectedStationName
    property string selectedStationDesc: appState.selectedStationDesc

    property string fromWhere : camFromView()


    function camFromView()
    {
        if(appState.selectedRailRoad == "lrt1"){
            return "lrt1InfoView"
        }else if(appState.selectedRailRoad == "lrt2"){
            return "lrt2InfoView"
        }else if(appState.selectedRailRoad == "mrt3"){
            return "mrt3InfoView"
        }
        return "";
    }

    function loadMap(categoryName , landmarkName , lat , longi )
    {
        appState.selectedLandmarkLat = lat ;
        appState.selectedLandmarkLong = longi ;
        appState.landMarkOnOff = true;
        appState.landMarkImage = "./content/" + categoryName + ".png"
        appState.selectedLandMark = landmarkName ;
        appState.cameFromView = "stationInfoView";
        appState.currentViewName = "stationMapView";

    }

    //width: 360
    //height: 640
    width: screen.displayHeight
    height:screen.displayWidth

    StationInfoViewModel{
        id: stationInfoModel
        cateId: appState.stationCateId

        onStatusChanged: {
            // Util.log(model.source)
            if (status == XmlListModel.Ready) {
                waitIndicator.show = false ;
                Util.log("StationInfoViewModel Status: ready")
            } else if (status == XmlListModel.Error) {
                Util.log("StationInfoViewModel Status: error")
            } else if (status == XmlListModel.Loading) {
                Util.log("StationInfoViewModel Status: loading")
            }
        }
    }

    Component.onCompleted: {

        appState.cameFromView = camFromView()
        //showInfo.show();

        Util.log("Station Info View Loaded = Came from " + appState.cameFromView )
    }

    Component{
        id: listViewDelegate
        Item{
            id: itemId
            width:container.width
            height: 60
            anchors.leftMargin: 0
            Rectangle{
                width: parent.width
                height: parent.height
                color:  "white"
                opacity: 1
                anchors.topMargin: 3
                Row{
                    spacing:3
                    Image{
                        id :categoryNameId
                        height: 60
                        fillMode: Image.PreserveAspectFit
                        width: 60
                        source: "./content/" +  categoryName + ".png"
                        anchors.verticalCenter: parent.verticalCenter
                        //text : categoryName
                    }
                    Column{

                        width: 290
                        height : addressRec.height + landMarkRec.height
                        Rectangle{
                            id: landMarkRec
                            width: 400
                            height: 30
                            color: "#f2f4f3"                         
                            Text{
                                id : landMarkNameId
                                text : landmarkName
                                width: 400
                                height: 30
                                font.pointSize : visual.defaultFontSize
                                verticalAlignment: Text.AlignVCenter
                                color: "black"
                            }
                            MouseArea{
                                anchors.fill: parent

                                onClicked: {
                                    landMarkNameId.color = "#f2f4f3"
                                    addressId.color="#f2f4f3"
                                    landMarkRec.color = "#e96668"
                                    addressRec.color = "#e96668"
                                    loadMap( categoryName , landmarkName , latitude , longitude) ;
                                    Util.log("Clicked LandMark map :" + "latitude =" +  latitude + " longitude" + longitude);
                                }
                            }
                        }
                        Rectangle{
                            id: addressRec
                            width: 400
                            height: 28
                            color: "#f2f4f3"                            
                            Text{
                                id : addressId
                                text : address + "," + city
                                width: 400
                                height: 28
                                font.pointSize : visual.defaultFontSize
                                verticalAlignment: Text.AlignVCenter
                                color: "black"
                            }
                            MouseArea{
                                anchors.fill: parent
                                onClicked: {
                                    landMarkNameId.color = "#f2f4f3"
                                    addressId.color="#f2f4f3"
                                    landMarkRec.color = "#e96668"
                                    addressRec.color = "#e96668"
                                    loadMap( categoryName , landmarkName , latitude , longitude) ;
                                    Util.log("Clicked LandMark map :" + "latitude =" +  latitude + " longitude" + longitude);
                                }
                            }

                        }

                    }

                }

            }
        }

    }

    Rectangle{
        id : subTitle
        width: parent.width
        height: 60
        color: "white"
        anchors.left: parent.left
        anchors.leftMargin: 0
        anchors.top: parent.top

        Row{
            spacing: 5
            Text{
                text : "NEARBY"
                width: 200
                color : "#dc143c"
                font.pointSize: visual.defaultFontSize
                height: 60
                font.family: visual.defaultFontFamily
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
            }
            Text{
                text : "|"
                color : "lightgray"
                width: 3
                height: 60
                horizontalAlignment: Text.AlignHCenter
                font.pointSize: visual.defaultFontSize
                font.family: visual.defaultFontFamily
                verticalAlignment: Text.AlignVCenter
            }
            Text{
                id: mapTxtButton
                text : "MAP"
                color : "#dc143c"
                font.pointSize: visual.defaultFontSize
                width: 150
                height: 60
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                font.family: visual.defaultFontFamily
                MouseArea{
                    anchors.fill: parent

                    onPressed: {
                        mapTxtButton.color = "lightGray"
                    }

                    onReleased: {
                        mapTxtButton.color = "#dc143c"
                    }


                    onClicked: {
                        appState.cameFromView = "stationInfoView";
                        appState.currentViewName = "stationMapView";
                        // container.stationMapClicked(buttonName) ;
                        Util.log("Clicked Station map");
                    }
                }
            }
            Button{
                id: openPop
                buttonName : appState.selectedStationId
                text : "Info"
                height: 60
                anchors.verticalCenter: parent.verticalCenter
                fontSize: visual.defaultFontSize
                onClicked: {
                    showInfo.show();
                    Util.log("Clicked Popup info map")

                }
            }

        }
    }

    ListView{
        id:listView
        model: stationInfoModel
        delegate: listViewDelegate        
        clip: true
        width: parent.width
        focus: true
        //highlight: Rectangle { color: "lightsteelblue"; radius : 3 }

        anchors {
            top: subTitle.bottom
            left: parent.left
            right: parent.right
            bottom: parent.bottom
            topMargin: 0
            leftMargin: container.margins
        }

    }
    ScrollBar { scrollArea: listView; width: container.scrollBarWidth; anchors.top: listView.top; anchors.right: listView.right; anchors.bottom: listView.bottom }

    WaitIndicator
    {
        id: waitIndicator
        // Always define the size for the WaitIndicator.
        anchors.fill: listView

        // Start showing the WaitIndicator immediately.
        // Otherwise it'll wait for one second before starting the indicator.
        delay: 0

        // Make sure it's on top of everything, so that the
        // Fader will capture key clicks
        z: 120

        // In real application, the WaitIndicator could be bound to
        // some "loading" appState variable etc.
        waitMessage : "Loading Nearby Places"
        show :true // container.loading
    }

    ModalInfo{
        id: showInfo
        fontSize : visual.defaultFontSize
        text: appState.selectedStationDesc
        showCancelButton: false
        z: 150
    }



}
