import QtQuick 1.0
import "./js/Util.js" as Util

Item {
    id: container

    Visual{
        id: visual
    }

    property string fontName: visual.defaultFontFamily
    property int fontSize: visual.defaultFontSize
    property int fontSizeTitle: visual.stationInfoViewTitleSize
    property color fontColor: visual.stationInfoViewDescFontColor
    property color fontColorTitle: visual.stationInfoViewDescFontColor
    property color fontColorLink: visual.defaultFontColorLink
    property double margins: visual.margins
    property int spacing: visual.spacing

    property int scrollBarWidth: visual.scrollBarWidth

    property string selectedStationId: appState.selectedStationId
    property string selectedStationName: appState.selectedStationName
    property string selectedStationDesc: appState.selectedStationDesc

    width: 360
    height: 1000


    Component.onCompleted: {
        Util.log("basicInfoView Loaded")

    }

    Flickable{
        id: flicker
        anchors{
            fill: container
            margins: container.margins
        }
        contentWidth: width
        contentHeight: column.height

        Column{
            id: column
            width: parent.contentWidth
            spacing: container.margins + 10
            Column{
                spacing: container.margins
                Row{
                    spacing: container.margins
                    Image{
                        id: icon
                        width: 40
                        height: 40
                        source: "./content/info_button.png"
                        fillMode: Image.PreserveAspectFit
                        smooth: true
                    }
                    Text {
                        height: parent.height
                        smooth: true
                        anchors.verticalCenter: icon.verticalCenter
                        anchors.margins: container.margins
                        text: container.selectedStationName
                        color: container.fontColor
                        font {
                            family: container.fontName
                            pointSize: container.fontSizeTitle
                        }
                    }
                }
                Text{
                    id:empty
                }
            }
            Column{
                spacing: container.margins

                Row{
                    spacing: container.margins
                    Image{
                        id: icon2
                        width: 17
                        height: 17
                        source: "./content/button_pressed.png"
                        fillMode: Image.PreserveAspectFit
                        smooth: true
                    }
                    Text {
                        height: parent.height
                        smooth: true
                        anchors.verticalCenter: icon2.verticalCenter
                        anchors.margins: container.margins
                        text: "Description"
                        color: container.fontColor
                        font {
                            family: container.fontName
                            pointSize: container.fontSize + 2
                            bold:true
                        }
                    }
                }
                Text{
                    id: desc
                    wrapMode: Text.WordWrap
                    width: flicker.width
                    text : appState.selectedStationDesc
                    color: container.fontColor
                    font {
                        family: container.fontName
                        pointSize: container.fontSize
                    }
                }
            }
            Column{
                spacing: container.margins
                Row{
                   spacing: container.margins
                   Image{
                       id: icon3
                       width: 17
                       height: 17
                       source: "./content/button_pressed.png"
                       fillMode: Image.PreserveAspectFit
                       smooth: true
                   }
                   Text {
                       height: parent.height
                       smooth: true
                       anchors.verticalCenter: icon3.verticalCenter
                       anchors.margins: container.margins
                       text: "Landmark"
                       color: container.fontColor
                       font {
                           family: container.fontName
                           pointSize: container.fontSize +2
                           bold:true
                       }
                   }
                }
                Text{
                    id: landmark
                    wrapMode: Text.WordWrap
                    width: flicker.width
                    text : appState.selectedStationDesc2
                    color: container.fontColor
                    font {
                        family: container.fontName
                        pointSize: container.fontSize
                    }
                }
            }
        }

    }

    // ScrollBar indicator. Take the bottommost search field height into account.
    ScrollBar{
        id: scrollBar
        scrollArea: flicker
        height: flicker.height
        width: container.scrollBarWidth
        anchors.right: container.right
    }
}
