import QtQuick 1.0
import QtMobility.location 1.1
import "./js/Util.js" as Util
import com.nokia.meego 1.0

PageStackWindow {
    id: appWindow

    showStatusBar: false
    showToolBar: false
    initialPage: mainW
    Page{
        id: mainW
        anchors.fill: parent
        orientationLock: PageOrientation.LockPortrait


Rectangle {
    id: mainWindow

    anchors.fill: parent
    anchors.centerIn: parent
//    width: screen.displayWidth
//    height:screen.displayHeight

    //width:screen.displayHeight
    color: "white" //visual.applicationBackgroundColor
    state: "showingSplashScreen"



    Component.onCompleted: {
        Util.log("main.qml loaded, width: " + width + " height: " + height)
        viewSwitcher.switchView(basicInfoView, 0, true);
    }

    Visual{
        id: visual
        //Component.onCompleted: appState.loading = true
    }

    AppStateVars{
        id: appState
        loading: true
    }

    Rectangle{
        color: "#990000"
        anchors.fill: naviBarHorizontal
        anchors.top: naviBarHorizontal.top
        anchors.bottom: naviBarHorizontal.bottom
        anchors.left: naviBarHorizontal.left
        anchors.right: naviBarHorizontal.right
//      width:360
//        height: mainWindow.height * 0.12
        gradient: Gradient{
            GradientStop { position: 0.0; color: "#ee575d" }
            GradientStop { position: 1.0; color: "#c42929" }
        }
    }

    // Wait indicator is also not visible by default, only when mainWindow.loading === true
    WaitIndicator{
        id: waitIndicator
        anchors.centerIn: mainWindow
        width: mainWindow.width
        height: mainWindow.height
        z: 120
        show: appState.loading
    }



     // All views have a title bar
    TitleBar{
        id: titleBar
        // Anchors titlebar to left,top and right. Then set height
        // Use grouping if possible.
        anchors{
            top : mainWindow.top
            left : mainWindow.left
            right : mainWindow.right
            leftMargin : 0
            rightMargin : 0

        }
        //height: appState.inLandscape ? mainWindow.width * 0.12 : mainWindow.height * 0.12
        height: 50

        //icont.visible : false
        title: ""
        titleImageSource: visual.titleImageSource
        titleFontSize: visual.titleFontSize
        titleFontColor: visual.titleFontColor
        titleFontBold: true
        titleBackgroundColor: visual.titleBackgroundColor
        captionFontName: visual.captionFontFamily
        captionFontSize: visual.captionFontSize
        captionFontColor: visual.captionFontColor
        captionBackgroundColor: visual.captionBackgroundColor
        caption: appState.currentCaption
        exitButtonSource: visual.exitButtonSource
        exitButtonPressedSource: visual.exitButtonPressedSource
        backButtonSource: visual.backButtonSource
        backButtonPressedSource: visual.backButtonPresseSource
        showingBackButton: false

        onBackButtonClicked: {
            Util.log("Back-button clicked. Came from view: " + viewName);
            appState.currentViewName = viewName;
        }

        onExitButtonClicked: {
            Util.exitApp("Exit-button clicked");
        }

        Component.onCompleted:{
            appState.loading = false
            Util.log("Loaded TitleBar")
        }
    }

    Item{
        id: contentPane
        clip:  true
        anchors{
            top: titleBar.bottom
            left: mainWindow.left
            //right: naviBarVertical.left
            right: parent.right
            bottom: naviBarHorizontal.top
        }
        // View switcher component, handles the view switching and animation
        ViewSwitcher{
            id: viewSwitcher
            root: contentPane
        }

        ViewLoader{
            id: basicInfoView
            viewSource: "BasicInfoView.qml"  // Basic information about MRT/LRT
            keepLoaded: true
        }

        ViewLoader{
            id: lrt1InfoView
            viewSource: "RailRoadInfoView.qml"  // Basic information about MRT/LRT
            keepLoaded: true
        }

        ViewLoader{
            id: lrt2InfoView
            viewSource: "RailRoadInfoView.qml"  // Basic information about MRT/LRT
            keepLoaded: true
        }

        ViewLoader{
            id: mrt3InfoView
            viewSource: "RailRoadInfoView.qml"  // Basic information about MRT/LRT
            keepLoaded: true
        }

        ViewLoader{
            id: stationInfoView
            viewSource: "StationInfoView.qml"
            keepLoaded: false
        }

        ViewLoader{
            id: stationMapView
            viewSource: "StationMapView.qml"
            keepLoaded: false
        }

        ViewLoader{
            id: nearMeView
            viewSource: "NearMeView.qml"
            keepLoaded: false
        }
    }

    TabBar{
        id: naviBarHorizontal
        //show: !appState.inLandscape
        wide: true

        anchors{
            bottom:  mainWindow.bottom
            left: mainWindow.left
            right: mainWindow.rigt
        }
        height: mainWindow.height * 0.12

        fontName: visual.tabBarButtonFont
        fontSize: visual.tabBarButtonFontSize
        fontColor: visual.tabBarButtonFontColor

        // Set graphics for tab bar buttons
        button1Background: visual.basicInfoButtonSource
        button1BackgroundSelected: visual.basicInfoButtonPressedSource

        button2Background: visual.myLocationButtonSource
        button2BackgroundSelected: visual.myLocationButtonPressedSource

        button3Background: visual.lrt1InfoButtonSource
        button3BackgroundSelected: visual.lrt1InfoButtonPressedSource

        button4Background: visual.lrt2InfoButtonSource
        button4BackgroundSelected: visual.lrt2InfoButtonPressedSource

        button5Background: visual.mrtInfoButtonSource
        button5BackgroundSelected: visual.mrtInfoButtonPressedSource

        //state: show ? "visible" : "hidden"
//        states: [
//            State {
//                name: "hidden"
//                AnchorChanges {
//                    target: naviBarHorizontal
//                    anchors.top: mainWindow.bottom
//                    anchors.bottom: undefined
//                }
//            }
//        ]

//        onSelectedButtonChanged: naviBarVertical.selectedButton = naviBarHorizontal.selectedButton

        onTabButtonClicked: {
            Util.log("Tab-bar button clicked: " + buttonName + "Target View Name : " + targetView );
            appState.cameFromView = targetView
            if(buttonName == "lrt1Button")
            {
                appState.selectedRailRoad = "lrt1"
            }else if(buttonName == "lrt2Button")
            {
                appState.selectedRailRoad = "lrt2"
            }else if(buttonName == "mrt3Button")
            {
                appState.selectedRailRoad = "mrt3"
            }else{
                appState.selectedRailRoad = ""
            }
            appState.currentViewName = targetView
        }
    }



    states: [
        State {
            when: appState.currentViewName === "nearMeView";
            name: "showingNearMeView"
            // Animate the view switch with viewSwitcher
           // PropertyChanges { target: myPositionSource ; active : false }
           // PropertyChanges { target: titleBar; showingBackButton: true }
            PropertyChanges { target: appState; landMarkOnOff: false }
            PropertyChanges { target: appState; currentCaption: "Near Me" }
            StateChangeScript { script: viewSwitcher.switchView(nearMeView,0, 0); }

        },
        State {
            when: appState.currentViewName === "basicInfoView";
            name: "showingBasicInfoView"
            // Animate the view switch with viewSwitcher
           // PropertyChanges { target: myPositionSource ; active : false }
            PropertyChanges { target: appState; landMarkOnOff: false }
            PropertyChanges { target: appState; currentCaption: "Basic Information" }
            StateChangeScript { script: viewSwitcher.switchView(basicInfoView,1, 0); }

        },

        State {
            when: appState.currentViewName === "stationInfoView";
            name: "showingStationInfoView"
            PropertyChanges { target: appState; landMarkOnOff: false }
            PropertyChanges { target: appState; currentCaption: appState.selectedStationId }
            PropertyChanges { target: mainWindow; color: visual.stationInfoViewBackground }
            PropertyChanges { target: titleBar; showingBackButton: true }
            StateChangeScript { script: viewSwitcher.switchView(stationInfoView,1, 0); }
        },
        State {
            when: appState.currentViewName === "stationMapView";
            name: "showingStationMapView"
            PropertyChanges { target: mainWindow; color: visual.stationInfoViewBackground }
            PropertyChanges { target: titleBar; showingBackButton: true }
            PropertyChanges { target: appState; currentCaption: appState.selectedStationId }
            //PropertyChanges { target: appState; currentCaption: appState.selectedStationId }
            //PropertyChanges { target: appState; cameFromView: "lrt1InfoView" }
            StateChangeScript { script: viewSwitcher.switchView(stationMapView,1, 0); }
        },
        State {
            when: appState.currentViewName === "lrt1InfoView";
            name: "showingLrt1InfoView"
            PropertyChanges { target: appState; landMarkOnOff: false }
            PropertyChanges { target: appState; currentCaption: "LRT 1" }
            StateChangeScript { script: viewSwitcher.switchView(lrt1InfoView,0, 0); }
        },
        State {
            when: appState.currentViewName === "lrt2InfoView";
            name: "showingLrt2InfoView"
            PropertyChanges { target: appState; currentCaption: "LRT 2" }
           // PropertyChanges { target: selectedLandMark; currentCaption: "" }
            PropertyChanges { target: appState; landMarkOnOff: false }
          //  PropertyChanges { target: myPositionSource ; active : false }
            StateChangeScript { script: viewSwitcher.switchView(lrt2InfoView,0, 0); }
        },
        State {
            when: appState.currentViewName === "mrt3InfoView";
            name: "showingMrt3InfoView"
           // PropertyChanges { target: selectedLandMark; currentCaption: "" }
            PropertyChanges { target: appState; currentCaption: "MRT 3" }
            PropertyChanges { target: appState; landMarkOnOff: false }
            StateChangeScript { script: viewSwitcher.switchView(mrt3InfoView,0, 0); }
        }
    ]
}
}
}

//import QtQuick 1.1
//import com.nokia.meego 1.0

//PageStackWindow {
//    id: appWindow

//    initialPage: mainPage

//    MainPage {
//        id: mainPage
//    }

//    ToolBarLayout {
//        id: commonTools
//        visible: true
//        ToolIcon {
//            platformIconId: "toolbar-view-menu"
//            anchors.right: (parent === undefined) ? undefined : parent.right
//            onClicked: (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close()
//        }
//    }

//    Menu {
//        id: myMenu
//        visualParent: pageStack
//        MenuLayout {
//            MenuItem { text: qsTr("Sample menu item") }
//        }
//    }
//}
